@@ -53,6 +53,7 @@ class RestAPI(object):
 		self.__plans__ = {
 			"developer": {
 				"plan_id":None,
+				"price_id":None,
 				"rate_limit":None,
 				"rate_reset":None,
 				"api_keys":[],
@@ -60,6 +61,7 @@ class RestAPI(object):
 			},
 			"free": {
 				"plan_id":None,
+				"price_id":None,
 				"rate_limit":3,
 				"rate_reset":1, # in days.
 				"api_keys":[],
@@ -67,6 +69,7 @@ class RestAPI(object):
 			},
 			"premium": {
 				"plan_id":"prod_I41OYB.....",
+				"price_id":"price_1Hp9g.....",
 				"rate_limit":10000,
 				"rate_reset":30, # in days.
 				"api_keys":[],
@@ -74,6 +77,7 @@ class RestAPI(object):
 			},
 			"pro": {
 				"plan_id":"prod_IPiu7a.....",
+				"price_id":"price_1HTnI.....",
 				"rate_limit":25000,
 				"rate_reset":30, # in days.
 				"api_keys":[],
@@ -332,7 +336,9 @@ class RestAPI(object):
 
 		# get subs.
 		response = self.get_subscriptions()
-		if response["error"] != None: return response
+		if response["error"] != None: 
+			if silent == False: print(f"Error: {response['error']}")
+			return response
 		subscriptions = response["subscriptions"]
 		if silent == False: print(f"Found {len(subscriptions)} subscriptions.")
 
@@ -343,7 +349,9 @@ class RestAPI(object):
 				for plan, info in plans.items():
 					if info["plan_active_status"]:
 						response = self.__get_plan_by_plan_id__(info["plan_id"])
-						if response["error"] != None: return response
+						if response["error"] != None: 
+							if silent == False: print(f"Error: {response['error']}")
+							return response
 						l_plan = response["plan"]
 						l_rank = self.__plans__[l_plan]["rank"]
 						if plan == None:
@@ -360,7 +368,9 @@ class RestAPI(object):
 				for plan in plans:
 					if silent == False: print(f"Canceling double subscription {uid}:{l_plan}.")	
 					response = self.cancel_subscription(uid=uid, plan=plan)
-					if response["error"] != None: return response
+					if response["error"] != None: 
+						if silent == False: print(f"Error: {response['error']}")
+						return response
 		# reset.
 		for plan in list(self.__plans__.keys()):
 			self.__plans__[plan]["api_keys"] = []
@@ -382,13 +392,17 @@ class RestAPI(object):
 			data = None
 			if response["error"] != None:
 				response = self.__save_new_user__(uid)
-				if response["error"] != None: return response
+				if response["error"] != None: 
+					if silent == False: print(f"Error: {response['error']}")
+					return response
 				data = response["data"]
 
 			# handle existing data.
 			else: 
 				response = self.__check_existing_user__(uid, response["document"], plans=plans)
-				if response["error"] != None: return response
+				if response["error"] != None: 
+					if silent == False: print(f"Error: {response['error']}")
+					return response
 				data = response["data"]
 
 			# map api keys.
